@@ -81,23 +81,31 @@ Pastebin::Pastebin(QObject *parent, const QVariantList &args)
             this, SLOT(sourceRemoved(QString)));
 }
 
+// save history of URLs
+void Pastebin::saveHistory()
+{
+    QString history;
+    const int numberOfActionHistory = m_actionHistory.size();
+    for (int i = 0; i < numberOfActionHistory; ++i) {
+        history.prepend(m_actionHistory.at(i)->toolTip());
+        history.prepend('|');
+    }
+
+    KConfigGroup cg = config();
+    cg.writeEntry("History", history);
+}
+
 Pastebin::~Pastebin()
 {
     delete m_topSeparator;
     delete m_bottomSeparator;
     delete m_newStuffDialog;
 
-    // save history of URLs
-    QString history;
+    saveHistory();
     const int numberOfActionHistory = m_actionHistory.size();
     for (int i = 0; i < numberOfActionHistory; ++i) {
-        history.prepend(m_actionHistory.at(i)->toolTip());
-        history.prepend('|');
         delete m_actionHistory.at(i);
     }
-
-    KConfigGroup cg = config();
-    cg.writeEntry("History", history);
 }
 
 void Pastebin::init()
@@ -466,6 +474,7 @@ void Pastebin::createConfigurationInterface(KConfigDialog *parent)
     uiConfig.setupUi(general);
 
     connect(parent, SIGNAL(okClicked()), this, SLOT(configAccepted()));
+    connect(parent, SIGNAL(applyClicked()), this, SLOT(configAccepted()));
     parent->addPage(general, i18n("General"), Applet::icon());
 
     uiConfig.ghnsButton->setIcon(KIcon("get-hot-new-stuff"));
@@ -475,7 +484,7 @@ void Pastebin::createConfigurationInterface(KConfigDialog *parent)
     uiConfig.textServer->setCurrentItem(cg.readEntry("TextProvider", m_txtServers.keys().at(0)));
     uiConfig.imageServer->setCurrentItem(cg.readEntry("ImageProvider", m_imgServers.keys().at(0)));
     uiConfig.historySize->setValue(m_historySize);
-    
+
     connect(uiConfig.textServer , SIGNAL(currentIndexChanged(int)) , parent, SLOT(settingsModified()));
     connect(uiConfig.imageServer , SIGNAL(currentIndexChanged(int)) , parent, SLOT(settingsModified()));
     connect(uiConfig.historySize , SIGNAL(valueChanged(int)) , parent, SLOT(settingsModified()));
@@ -490,6 +499,7 @@ void Pastebin::configAccepted()
     cg.writeEntry("TextProvider", uiConfig.textServer->currentText());
     cg.writeEntry("ImageProvider", uiConfig.imageServer->currentText());
     cg.writeEntry("HistorySize", historySize);
+    saveHistory();
 
     emit configNeedsSaving();
 }
