@@ -140,13 +140,29 @@ class CachedProvider : public ComicProvider
          */
         virtual KUrl websiteUrl() const;
 
+        virtual KUrl imageUrl() const;
+
         /**
          * Returns the shop website of the comic.
          */
         virtual KUrl shopUrl() const;
 
+        /**
+          * Returns the maximum number of cached strips per comic, -1 means that there is no limit
+          * @note defaulte is -1
+          */
+        static int maxComicLimit();
+
+        /**
+          * Sets the maximum number of cached strips per comic, -1 means that there is no limit
+          */
+        static void setMaxComicLimit( int limit );
+
     private Q_SLOTS:
         void triggerFinished();
+
+    private:
+        static const int CACHE_DEFAULT;
 };
 
 #endif
