@@ -1,12 +1,12 @@
 /*
  *   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
- *   Copyright  2008 by Anne-Marie Mahfouf <annma@kde.org>                 
+ *   Copyright  2008 by Anne-Marie Mahfouf <annma@kde.org>
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
  *
- *   This program is free software; you can redistribute it and/or modify  
- *   it under the terms of the GNU General Public License as published by  
- *   the Free Software Foundation; either version 2 of the License, or     
- *   (at your option) any later version.  
- *                                 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,7 +20,6 @@
 
 #include "apodprovider.h"
 
-#include <QtCore/QDate>
 #include <QtCore/QRegExp>
 #include <QtGui/QImage>
 
@@ -43,7 +42,6 @@ class ApodProvider::Private
 
     ApodProvider *mParent;
     QByteArray mPage;
-    QDate mDate;
     QImage mImage;
 };
 
@@ -51,25 +49,23 @@ void ApodProvider::Private::pageRequestFinished( KJob *_job )
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>( _job );
     if ( job->error() ) {
-	emit mParent->error( mParent );
-	return;
+        emit mParent->error( mParent );
+        return;
     }
-    
-    const QString data = QString::fromUtf8( job->data() );
-    
-    const QString pattern( "<IMG SRC=\"image/*.jpg" );
-    QRegExp exp( pattern );
-    exp.setPatternSyntax(QRegExp::Wildcard);
-    
-    int pos = exp.indexIn( data ) + pattern.length();
-    
-    const QString sub = data.mid( pos, exp.matchedLength() -21);
-    kDebug() << "####### sub " << sub << endl; //TODO should return *.jpg
-    
-    KUrl url( QString( "http://antwrp.gsfc.nasa.gov/apod/image/%1/%2" ).arg(QDate::currentDate().toString( "yyMM" ) ).arg( sub ) );
 
-    KIO::StoredTransferJob *imageJob = KIO::storedGet( url );
-    mParent->connect( imageJob, SIGNAL( finished( KJob* ) ), SLOT( imageRequestFinished( KJob* ) ) );
+    const QString data = QString::fromUtf8( job->data() );
+
+    const QString pattern( QLatin1String( "<a href=\"(image/.*)\"" ) );
+    QRegExp exp( pattern );
+    exp.setMinimal( true );
+    if ( exp.indexIn( data ) != -1 ) {
+        const QString sub = exp.cap(1);
+        KUrl url( QString( QLatin1String( "http://antwrp.gsfc.nasa.gov/apod/%1" ) ).arg( sub ) );
+        KIO::StoredTransferJob *imageJob = KIO::storedGet( url, KIO::NoReload, KIO::HideProgressInfo );
+        mParent->connect( imageJob, SIGNAL(finished(KJob*)), SLOT(imageRequestFinished(KJob*)) );
+    } else {
+        emit mParent->error( mParent );
+    }
 }
 
 void ApodProvider::Private::imageRequestFinished( KJob *_job )
@@ -87,15 +83,9 @@ void ApodProvider::Private::imageRequestFinished( KJob *_job )
 ApodProvider::ApodProvider( QObject *parent, const QVariantList &args )
     : PotdProvider( parent, args ), d( new Private( this ) )
 {
-    const QString type = args[ 0 ].toString();
-    if ( type == "Date" )
-        d->mDate = args[ 1 ].toDate();
-    else
-	Q_ASSERT( false && "Invalid type passed to potd provider" );
-
-    KUrl url( QString( "http://antwrp.gsfc.nasa.gov/apod/" ) );
-    KIO::StoredTransferJob *job = KIO::storedGet( url );
-    connect( job, SIGNAL( finished( KJob *) ), SLOT( pageRequestFinished( KJob* ) ) );
+    KUrl url( QLatin1String( "http://antwrp.gsfc.nasa.gov/apod/" ) );
+    KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::NoReload, KIO::HideProgressInfo );
+    connect( job, SIGNAL(finished(KJob*)), SLOT(pageRequestFinished(KJob*)) );
 }
 
 ApodProvider::~ApodProvider()
@@ -108,9 +98,4 @@ QImage ApodProvider::image() const
     return d->mImage;
 }
 
-QString ApodProvider::identifier() const
-{
-    return QString( "apod:%1" ).arg( d->mDate.toString( Qt::ISODate ));
-}
-
 #include "apodprovider.moc"
